pub struct AstronomyDay {
pub date: DateTime,
pub daylength: Option<String>,
pub moonphase: Option<MoonPhase>,
pub events: Vec<AstronomyDayEvent>,
}Expand description
Information about an astronomical object for a specific day.
Fields
date: DateTimeDate for the current information.
daylength: Option<String>Length of this day (time between sunrise and sunset). If the sun is not up on this day, 00:00:00 will be reported. If the sun does not set on this day, the value will read 24:00:00. Attribute only applies for the sun object and if requested.
moonphase: Option<MoonPhase>Moon phase for the day. Only if requested.
events: Vec<AstronomyDayEvent>Lists all events during the day.